CREATE OR REPLACE FUNCTION public.f_replace_punctuation_squash_text(phrase_in   text)
  RETURNS text AS
$BODY$
---------------------------------------------------------------------------------------
--
--    This function replaces a lot of the standard punctuation characters with a
--    the one significant punctuation mark '-' hyphen.
--
--    The plus sign is still significant.
--
--    Example:
--
--          select * from f_replace_punctuation_squash_text(E'--\\Brian------N/Ce c#&[]c+re,l#&(*l-')
--
---------------------------------------------------------------------------------------
declare
   phrase_out              text;
begin
   phrase_out := regexp_replace(phrase_in,  '[/_]', '-', 'g');

   return phrase_out;
end;
$BODY$
  LANGUAGE 'plpgsql' IMMUTABLE STRICT
  cost 5;
  

CREATE OR REPLACE FUNCTION public.f_squash_text(phrase_in   text)
  RETURNS text AS
$BODY$
---------------------------------------------------------------------------------------
--
--    We use this function to equate vp_codes to other vp_codes.
--    We use this function to equate mp_codes to other mp_codes.
--
--    We do NOT use this function for tsearch.  Tsearch transforms text using more 
--    relaxed rules.   Remember, we use f_squash to EQUATE, not to rank.
--
--    If f_squash(code1) = f_squash(code2), then code1 equals code2.
-- 
--    The function returns the word with no white spaces.
--    The function returns the word in lower case. 
--    The function removes most punctuation characters.   Only a hyphen survives.
--    The function replaces forward slash and underscore with a hyphen.   
--
--    Example:
--
--       select * from f_squash_text(E'0-00--\\BriAn------N/Ce c#&[]ca+re,l#&(*l+i-----')
--
--    The select statement will return:
--
--       brian-n-ceccarelli
--
---------------------------------------------------------------------------------------
declare
   phrase_out              text;
begin

   phrase_out   := public.f_replace_punctuation_squash_text(lower(phrase_in)::text);


   return phrase_out;
end;
$BODY$
  language 'plpgsql' immutable strict
  cost 7;


--------------------
--------------------

CREATE OR REPLACE FUNCTION public.f_replace_punctuation_squash_fb(phrase_in   text)
  RETURNS text AS
$BODY$
---------------------------------------------------------------------------------------
--
--    This function replaces a lot of the standard punctuation characters with a
--    the one significant punctuation mark '-' hyphen.
--
--    The plus sign is still significant.
--
--    Example:
--
--          select * from f_replace_punctuation_squash_fb(E'--\\Brian------N/Ce c#&[]c+re,l#&(*l-')
--
---------------------------------------------------------------------------------------
declare
   phrase_out              text;
begin
   phrase_out := regexp_replace(phrase_in,  '[/_]', '-', 'g');

   return phrase_out;
end;
$BODY$
  LANGUAGE 'plpgsql' IMMUTABLE STRICT
  cost 5;
  



CREATE OR REPLACE FUNCTION public.f_squash_fb(phrase_in   text)
  RETURNS text AS
$BODY$
---------------------------------------------------------------------------------------
--
--    We use this function to equate vp_codes to other vp_codes.
--    We use this function to equate mp_codes to other mp_codes.
--
--    We do NOT use this function for tsearch.  Tsearch transforms text using more 
--    relaxed rules.   Remember, we use f_squash to EQUATE, not to rank.
--
--    If f_squash(code1) = f_squash(code2), then code1 equals code2.
-- 
--    The function returns the word with no white spaces.
--    The function returns the word in lower case. 
--    The function removes most punctuation characters.   Only a hyphen survives.
--    The function replaces forward slash and underscore with a hyphen.   
--
--    Example:
--
--       select * from f_squash_fb(E'0-00--\\BriAn------N/Ce c#&[]ca+re,l#&(*l+i-----')
--
--    The select statement will return:
--
--       brian-n-ceccarelli
--
---------------------------------------------------------------------------------------
declare
   phrase_out              text;
begin

   phrase_out   := public.f_replace_punctuation_squash_fb(lower(phrase_in)::text);


   return phrase_out;
end;
$BODY$
  language 'plpgsql' immutable strict
  cost 7;




------------  Check Constraint Problem
  
drop table if exists public.mytable cascade;

create table public.mytable
(
my_id       int8          not null,
name        varchar(100),
constraint ckc_mytable_name check (public.f_squash_text(name::text) <> 'Brand'::text),
constraint pk_mytable primary key (my_id)
);


insert into public.mytable (my_id, name) values (1, 'Brian');
insert into public.mytable (my_id, name) values (2, 'Joan');
insert into public.mytable (my_id, name) values (3, null);
insert into public.mytable (my_id, name) values (4, 'Ray_Ceccarelli');


------ Function-Based Index Problem.

drop table if exists public.fbtable cascade;

create table public.fbtable
(
fb_id       int8          not null,
name        varchar(100),
constraint pk_fbtable primary key (fb_id)
);

insert into public.fbtable (fb_id, name) values (1, 'Ross');
insert into public.fbtable (fb_id, name) values (2, 'Fil-A O Fish');
insert into public.fbtable (fb_id, name) values (3, null);
insert into public.fbtable (fb_id, name) values (4, 'Ray_Ceccarelli dad');

create unique index fbtable_squash_name on fbtable (public.f_squash_fb(name::text));




  
  
